@@ -59,9 +59,7 @@ def backup(ctx):
         logger.info(f'filesystem={job.filesystem} '
                     f'cron="{job.cron}" '
                     'msg="Adding job."')
-        scheduler.add_job(job.start, 'cron', **job.cron,
-                          misfire_grace_time=2*60*60,
-                          coalesce=True)
+        scheduler.add_job(job.start, 'cron', **job.cron, coalesce=True)
 
     try:
         scheduler.start()
